unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ExtCtrls, StdCtrls, unSMSClient, unSMSMessage
  //Uncomment to see unicode SMS:
  //,QDialogs
  ;

type
  TForm1 = class(TForm)
    memoMessage: TMemo;
    eTo: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    bSend: TButton;
    Bevel1: TBevel;
    Bevel2: TBevel;
    memoLog: TMemo;
    Label3: TLabel;
    eHost: TEdit;
    Label4: TLabel;
    ePort: TEdit;
    Label5: TLabel;
    eUsername: TEdit;
    ePassword: TEdit;
    bConnect: TButton;
    Label6: TLabel;
    Label7: TLabel;
    bDisconnect: TButton;
    procedure FormCreate(Sender: TObject);
    procedure bConnectClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure bDisconnectClick(Sender: TObject);
    procedure bSendClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    mySMSClient : TSMSClient;
    procedure onClientConnected(Sender : TObject);
    procedure onClientDisconnected(Sender : TObject);
    procedure onClientConnectionError(Sender : TObject;errorCode: integer; errorMessage:string);
    procedure onMessageReceived(Sender : TObject;messageid : string;senderaddress : widestring; receiver : widestring;
      messagedata : widestring;  messagetype : string;  serviceprovider : string;
      sentdate : string; receiveddate : string);
    procedure onMessageAcceptedForDelivery(Sender : TObject;messageid : string;senderaddress : widestring; receiver : widestring;
      messagedata : widestring;  messagetype : string;  serviceprovider : string;
      sentdate : string; receiveddate : string
    );
    procedure onMessageDeliveredToNetwork(Sender : TObject;messageid : string; senderaddress : widestring; receiver : widestring;
      messagedata : widestring; messagetype : string; serviceprovider : string;
      sentdate : string;receiveddate : string
    );
    procedure onMessageDeliveredToHandset(Sender : TObject;messageid : string; senderaddress : widestring; receiver : widestring;
      messagedata : widestring; messagetype : string;  serviceprovider : string;
      sentdate : string;  receiveddate : string
    );
    procedure onMessageDeliveryError(Sender : TObject;messageid : string; senderaddress : widestring; receiver : widestring;
      messagedata : widestring; messagetype : string; serviceprovider : string;
      sentdate : string;receiveddate : string;
      errorCode:integer; errorMessage:widestring
    );
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

function getTimeStamp : string;
Begin
   Result := FormatDateTime('yyyy-mm-dd hh:nn:ss ',now);
End;

procedure TForm1.FormCreate(Sender: TObject);
begin
   bConnect.Enabled := true;
   bDisconnect.Enabled := false;
   memoMessage.Enabled := false;
   eTo.Enabled := false;
   bSend.Enabled := false;

   //Create SMS client
   mySMSClient := TSMSClient.Create(form1);

   //Wire up SMS client events
   mySMSClient.onClientConnected := onClientConnected;
   mySMSClient.onClientDisconnected := onClientDisconnected;
   mySMSClient.onClientConnectionError := onClientConnectionError;
   mySMSClient.onMessageAcceptedForDelivery := onMessageAcceptedForDelivery;
   mySMSClient.onMessageDeliveredToNetwork := onMessageDeliveredToNetwork;
   mySMSClient.onMessageDeliveredToHandset := onMessageDeliveredToHandset;
   mySMSClient.onMessageDeliveryError := onMessageDeliveryError;
   mySMSClient.onMessageReceived := onMessageReceived;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
    mySMSClient.free;
end;

procedure TForm1.bConnectClick(Sender: TObject);
begin
   mySMSClient.UserName := eUserName.Text;
   mySMSClient.Password := ePassword.Text;
   mySMSClient.Host := eHost.Text;
   mySMSClient.Port := strtoint(ePort.Text);
   mySMSClient.connected := true;
   if (not mySMSClient.connected) then begin
       showMessage('Could not connecto to SMS Gateway. Reason: '+
       mySMSClient.getLastErrorMessage);
   end else begin
       bConnect.Enabled := false;
       bDisconnect.Enabled := true;
       memoMessage.Enabled := true;
       eTo.Enabled         := true;
       bSend.Enabled       := true;
   end;
end;


procedure TForm1.bDisconnectClick(Sender: TObject);
begin
   if (mySMSClient.connected) then mySMSClient.connected := false;

   bConnect.Enabled := true;
   bDisconnect.Enabled := false;
   memoMessage.Enabled := false;
   eTo.Enabled := false;
   bSend.Enabled := false;
end;

procedure TForm1.bSendClick(Sender: TObject);
var
   msgID : string;
begin
   msgID := mySMSClient.sendMessage(eTo.Text,memoMessage.Text);
   MemoLog.lines.Add(getTimeStamp+'Submitting message to the SMS gateway with ID: '+msgID);
end;

//*********************************************************
//Events invoked by the SMSClient component
//*********************************************************

procedure TForm1.onClientConnected(Sender : TObject);
begin
   memoLog.lines.Add(getTimeStamp+'Successfully connected to the SMS gateway');
end;

procedure TForm1.onClientDisconnected(Sender : TObject);
begin
   memoLog.lines.Add(getTimeStamp+'Disconnected from the SMS gateway');
   bDisconnectClick(nil);
end;

procedure TForm1.onClientConnectionError(Sender: TObject; errorCode: integer; errorMessage:string);
begin
   memoLog.lines.Add(getTimeStamp+errorMessage);
end;

procedure TForm1.onMessageReceived(
      Sender: TObject;
      messageid : string;
      senderaddress : widestring;
      receiver : widestring;
      messagedata : widestring;
      messagetype : string;
      serviceprovider : string;
      sentdate : string;
      receiveddate : string);
begin
      memoLog.lines.Add(getTimeStamp+'SMS received. '+senderaddress+' '+messagedata);
      //Uncomment to see unicode SMS in dialog box
      //MessageDlg('Unicode Message Data',messagedata,mtConfirmation, [mbYes, mbNo], 0, mbYes);
end;

procedure TForm1.onMessageAcceptedForDelivery(
      Sender: TObject;
      messageid : string;
      senderaddress : widestring;
      receiver : widestring;
      messagedata : widestring;
      messagetype : string;
      serviceprovider : string;
      sentdate : string;
      receiveddate : string);
Begin
   memoLog.lines.Add(getTimeStamp+'Message accepted for delivery. ID: '+messageID);
End;

procedure TForm1.onMessageDeliveredToNetwork(
      Sender: TObject;
      messageid : string;
      senderaddress : widestring;
      receiver : widestring;
      messagedata : widestring;
      messagetype : string;
      serviceprovider : string;
      sentdate : string;
      receiveddate : string);
Begin
   memoLog.lines.Add(getTimeStamp+'Message delivered to network. ID: '+messageID);
End;

procedure TForm1.onMessageDeliveredToHandset(
      Sender: TObject;
      messageid : string;
      senderaddress : widestring;
      receiver : widestring;
      messagedata : widestring;
      messagetype : string;
      serviceprovider : string;
      sentdate : string;
      receiveddate : string);
Begin
   memoLog.lines.Add(getTimeStamp+'Message delivered to handset. ID: '+messageID);
End;

procedure TForm1.onMessageDeliveryError(
      Sender: TObject;
      messageid : string;
      senderaddress : widestring;
      receiver : widestring;
      messagedata : widestring;
      messagetype : string;
      serviceprovider : string;
      sentdate : string;
      receiveddate : string;
      errorCode:integer;
      errorMessage:widestring);
Begin
   memoLog.lines.Add(getTimeStamp+'Message could not be delivered. Error message: '+errorMessage);
End;


end.
